@@ -1,6 +1,7 @@
 import unittest
 
-from .__init__ import *
+from .configEnvUtil import *
+from .practical import *
 
 
 class Testenv(unittest.TestCase):
