@@ -1,7 +1,5 @@
 import unittest
 
-from .systemProcessingBase import *
-from ubelt import *
 from . import *
 
 
@@ -14,6 +12,6 @@ class TestSystemProcessingBase(unittest.TestCase):
 
     def test_2(self):
         pass
-        data = 取鼠标位置()
-        print(data.x)
-        print(data.y)
+        # data = 取鼠标位置()
+        # print(data.x)
+        # print(data.y)
