@@ -2,7 +2,7 @@
 兼容原生wx模块直接插上易函数的翅膀
 
 """
-from .component.__init__ import *
+from .component import *
 
 
 class AnimationCtrl( 动画框 , 公用方法):
@@ -120,8 +120,6 @@ class TimePickerCtrl( 时间框 , 公用方法):
 class Panel( 容器 , 公用方法):
     pass
 
-
-
 class Timer( 时钟 , 公用方法):
     pass
 
@@ -129,3 +127,9 @@ class Timer( 时钟 , 公用方法):
 class Image( 图片操作 , 公用方法):
     pass
 
+class Sound( 播放器 , 公用方法):
+    pass
+
+class Notebook( 选择夹 , 公用方法):
+    pass
+
