@@ -29,3 +29,10 @@ from .TimePickerCtrl import *
 from .Panel import *
 from .Timer import *
 from .Image import *
+from .Sound import *
+from .Propgrid import *
+from .Notebook import *
+from .Toolbar import *
+from .Menbar import *
+from .wxImageList import *
+from .WebView import *
